@@ -1,22 +1,25 @@
 """Simple, reusable and optimized XOR ciphers in Python."""
 
 __description__ = "Simple, reusable and optimized XOR ciphers in Python."
-__url__ = "https://github.com/RealistikDash/xor-cipher"
+__url__ = "https://github.com/xor-cipher/xor-cipher"
 
 __title__ = "xor_cipher"
-__author__ = "RealistikDash, nekitdev"
+__author__ = "nekitdev, RealistikDash"
 __license__ = "MIT"
-__version__ = "2.2.1"
+__version__ = "2.4.0"
 
 from xor_cipher.core import (
     DEFAULT_ENCODING,
     DEFAULT_ERRORS,
     FAST,
     cyclic_xor,
+    cyclic_xor_in_place,
+    cyclic_xor_in_place_unsafe,
     cyclic_xor_unsafe,
     cyclic_xor_string,
     cyclic_xor_string_unsafe,
     xor,
+    xor_in_place,
     xor_string,
 )
 
@@ -25,9 +28,12 @@ __all__ = (
     "DEFAULT_ERRORS",
     "FAST",
     "cyclic_xor",
+    "cyclic_xor_in_place",
+    "cyclic_xor_in_place_unsafe",
     "cyclic_xor_unsafe",
     "cyclic_xor_string",
     "cyclic_xor_string_unsafe",
     "xor",
+    "xor_in_place",
     "xor_string",
 )
